MagWords is a text-rendering library for OpenGL context. It provides clear text rendering without collapsion caused by scaling, fast initialization and drawing flow, and memory-saving internal representation of glyph data.

# Installation

To install MagWords and its required dependencies using pip, enter the following command at a shell: 

```
$ pip install magwords
```

# Contribute

Our project is still under development. Everyone is welcome to contribute. Bug reports and fixes are welcome, and suggestions for features would be appreciated!

Contribution guide is in preparation...

# License

[MIT License](LICENSE)